@@ -26,18 +26,23 @@ def test_straxen_context():
     ctx = straxen_db(by_category=False)
     assert ctx is not None
 
+
 def test_find_schema():
-    from xedocs.schemas import PmtGain
-    schema = xedocs.find_schema("pmt_gains")
+    from xedocs.schemas import XeDoc
 
-    assert schema is PmtGain
+    for name, schema in XeDoc._XEDOCS.items():
 
-    schema = xedocs.find_schema(PmtGain)
+        found_schema = xedocs.find_schema(name)
+        assert schema is found_schema
+
+        found_schema = xedocs.find_schema(schema.__name__)
+        assert schema is found_schema
+
+        found_schema = xedocs.find_schema(schema)
+        assert schema is found_schema
 
-    assert schema is PmtGain
 
 def test_command_line_interface():
     """Test the CLI."""
     runner = CliRunner()
     result = runner.invoke(cli.main)
-
