@@ -1,13 +1,13 @@
-
 """Attempt to register URConfig protocol if straxen
 is installed.
 """
 import straxen
+from xedocs import settings
 
 
 @straxen.URLConfig.register("xedocs")
 def xedocs_protocol(
-    name, db="straxen_db", sort=None, attr=None, as_list=False, **labels
+    name, db=settings.DEFAULT_DATABASE, sort=None, attr=None, as_list=False, **labels
 ):
     """URLConfig protocol for fetching values from
         a xedocs database.
@@ -25,10 +25,15 @@ def xedocs_protocol(
 
     accessor = getattr(schema, db)
 
-    if sort is not None:
-        labels['sort'] = sort
+    kwargs = straxen.filter_kwargs(accessor.find_docs, labels)
+    
+    if isinstance(sort, (str,list)):
+        kwargs["sort"] = sort
 
-    docs = accessor.find_docs(**labels)
+    if not as_list:
+        kwargs["limit"] = 1
+
+    docs = accessor.find_docs(**kwargs)
 
     if not docs:
         raise KeyError(f"No matching documents found for {name}.")
