@@ -11,6 +11,8 @@ class ApiAuth(AuthBase):
 
     def __call__(self, r: PreparedRequest) -> PreparedRequest:
         if self.authenticator is not None:
+            if self.authenticator.token is None:
+                self.authenticator.login()
             r.headers["Authorization"] = f"Bearer {self.authenticator.token}"
         return r
 
@@ -18,12 +20,13 @@ class ApiAuth(AuthBase):
 def api_client(url, token=None, authenticator=None, headers=None, client=None):
     headers = headers if headers is not None else {}
 
+    auth = None
+
     if token is not None:
-        auth = f"Bearer {token}"
+        headers["Authorization"] = f"Bearer {token}"
     elif authenticator is not None:
         auth = ApiAuth(authenticator)
-    else:
-        auth = None
+
     client = rframe.RestClient(
         url,
         headers=headers,
