@@ -1,7 +1,10 @@
 from .base_schemas import VersionedXeDoc, XeDoc
-from .bodega import Bodega
+from .detector_numbers import DetectorNumber
+from .context_config import ContextConfig
+from .context_lineage import ContextLineage
 from .fax import FaxConfig
 from .corrections import *
 from .calibrations import *
 from .operations_reports import *
-from .analysis import *
\ No newline at end of file
+from .analysis import *
+from .pmt_data import *
