@@ -11,8 +11,7 @@ def camel_to_snake(name):
 
 
 class XeDoc(rframe.BaseSchema):
-    __ANALYST_DB__: ClassVar[str] = "xedocs-dev"
-    __STRAXEN_DB__: ClassVar[str] = "xedocs"
+    """Base class for all xedocs schemas."""
 
     _ALIAS: ClassVar = ""
     _CATEGORY: ClassVar = "general"
@@ -30,8 +29,7 @@ class XeDoc(rframe.BaseSchema):
 
         if cls._ALIAS and cls._ALIAS not in cls._XEDOCS:
             cls._XEDOCS[cls._ALIAS] = cls
-            import xedocs
-            xedocs.register_default_storage(cls)   
+            settings.register_databases(cls)
 
     @classmethod
     def default_datasource(cls):
@@ -39,15 +37,8 @@ class XeDoc(rframe.BaseSchema):
         called and no datasource is passed.
         """
         import xedocs
-        return xedocs.get_datasource_for(cls)
 
-    @classmethod
-    def default_database_name(cls):
-        return "xedocs"
-
-    @classmethod
-    def default_collection_name(cls):
-        return cls._ALIAS
+        return xedocs.default_datasource_for(cls)
 
     @classmethod
     def help(cls):
