@@ -16,9 +16,9 @@ import rframe
 from .base_corrections import TimeSampledCorrection
 from ..constants import PARTITION
 
-class SingleElectronGain(TimeSampledCorrection):
-    
-    _ALIAS = "se_gains"
-    partition: PARTITION = rframe.Index(default='all_tpc')
-    value: float
 
+class SingleElectronGain(TimeSampledCorrection):
+
+    _ALIAS = "se_gains"
+    partition: PARTITION = rframe.Index(default="all_tpc")
+    value: float
