@@ -1,9 +1,6 @@
-
-
 import rframe
 import datetime
-from typing import List
-from pydantic import Field, BaseModel
+from pydantic import Field
 
 
 from .base_pmt_data import BasePmtData
@@ -11,7 +8,8 @@ from ..constants import DETECTOR
 
 
 class VoltageChange(BasePmtData):
-    
+    _ALIAS = "pmt_voltage_changes"
+
     detector: DETECTOR = rframe.Index()
     pmt: int = rframe.Index(ge=0)
     time: datetime.datetime = rframe.Index()
@@ -19,4 +17,4 @@ class VoltageChange(BasePmtData):
     old_voltage: float
     new_voltage: float
     operator: str = Field(max_length=60)
-    comments: str
\ No newline at end of file
+    comments: str
